#!/bin/csh

# Test calculation script for the GROMACS extension for S2 restraints
 
# Same suffix used for the configure script
set program_suffix = _mumo
# Molecule base name 
set molname = test
# Number of repliocas to use 
# (same number is used here for the number of processes to start)
set np=4

setenv GMX_DISRE_ENSEMBLE_SIZE $np;
# necessary to maintain parallel versions simultaneously, you
# also need to have the respective lib$program_suffix directories.
setenv LD_RUN_PATH /home/szpari/GROMACS/lib$program_suffix;
setenv LD_LIBRARY_PATH /home/szpari/GROMACS/lib$program_suffix;

# The perl scripts invoked below should be in a directory in your 
# $PATH. (They can be found in the 'scripts' directory' provided).

# multigromacs.pl runs the gromacs command specified with -C N times (specified 
# with -N). '#' is incremented from 0 to N-1 in the file names.
#
# mdp_randomseed.pl puts different random seeds to the mdp files
# to ensure that the staring velocities will be different for each replica

# Generating different random seed for each run input file
multigromacs.pl -N $np -C "mdp_randomseed.pl -f full.mdp -o full#.mdp"

# Grompp!
multigromacs.pl -N $np -C "grompp$program_suffix -f full#.mdp -c $molname'.gro' -p $molname.top -o $molname'_full#.tpr'"

# Run MD!
mpirun -np $np mdrun$program_suffix -multi $np -s $molname"_full.tpr" -o $molname"_full.trr" -c $molname"_full.gro" 




